<?xml version="1.0" encoding="UTF-8"?>
<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns="http://purl.org/rss/1.0/" xmlns:taxo="http://purl.org/rss/1.0/modules/taxonomy/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:syn="http://purl.org/rss/1.0/modules/syndication/" xmlns:admin="http://webns.net/mvcb/">
  <channel about="http://permalink.gmane.org/gmane.emacs.w3.devel">
    <title>gmane.emacs.w3.devel</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel</link>
    <description/>
    <syn:updatePeriod>hourly</syn:updatePeriod>
    <syn:updateFrequency>1</syn:updateFrequency>
    <syn:updateBase>1901-01-01T00:00+00:00</syn:updateBase>
    <items>
      <rdf:Seq>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5434"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5433"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5432"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5431"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5430"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5429"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5428"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5427"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5426"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5425"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5424"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5421"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5384"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5362"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5344"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5314"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5290"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5252"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5237"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.emacs.w3.devel/5160"/>
      </rdf:Seq>
    </items>
    <image rdf:resource="http://gmane.org/img/gmane-25t.png"/>
    <textinput rdf:resource=""/>
  </channel>
  <image rdf:about="http://gmane.org/img/gmane-25t.png">
    <title>Gmane</title>
    <url>http://gmane.org/img/gmane-25t.png</url>
    <link>http://gmane.org</link>
  </image>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5434">
    <title>Re: Compiling for CarbonEmacs on Mac OS X Tiger</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5434</link>
    <description>

Tried again with source pulled fresh from CVS.  Configured with:

./configure --with-emacs=/Applications/Emacs.app/Contents/MacOS/Emacs --with-gnus=/Applications/Emacs.app/Contents/Resources/lisp/gnus


Finally got it to compile!  However, invoking with M-x gnus gives the ff. error:

Wrong type argument: arrayp, nil

Any ideas anyone?  Pulled up http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=110778 in Google but I'm not sure this fix is applicable to Carbon Emacs.  The backtrace (username masked out) follows:

Debugger entered--Lisp error: (wrong-type-argument arrayp nil) 
  font-size(nil) 
  font-default-size-for-device(nil) 
  font-spatial-to-canonical("+12pt") 
  css-expand-length("+12pt" t) 
  css-expand-value(height "+12pt") 
  css-parse-args(238 257) 
  css-parse("file:/Users/xxxxxxxxxxxxxx/.emacs.d/w3-20080925/w3/default.css" nil nil) 
  w3-find-default-stylesheets() 
  w3-refresh-stylesheets() 
  w3-do-setup() 
  w3() 
  call-interactively(w3) 
  execute-extended-command(nil) 
  call-interactivel</description>
    <dc:creator>Chry Cheng</dc:creator>
    <dc:date>2008-09-28T06:09:00</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5433">
    <title>Compiling for CarbonEmacs on Mac OS X Tiger</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5433</link>
    <description>_______________________________________________
W3-dev mailing list
W3-dev&lt; at &gt;gnu.org
http://lists.gnu.org/mailman/listinfo/w3-dev
</description>
    <dc:creator>Christian Cheng</dc:creator>
    <dc:date>2008-09-18T18:21:44</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5432">
    <title>Introduction</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5432</link>
    <description>Hi All,

I've just joined the list. 
I use to use w3 a lot back in the late 90s, but then stopped using it due
to a number of issues. I'd like to get back to using it now and as there is
a chance I may have some spare coding cycles coming up, thought I might try
to contribute by fixing some of the problems I've encountered. 

By way of providing some background.....

I've been using emacs for just over 10 years. My background is as an
analyst/programmer, but with not much lisp/elisp experience (just enough to
be dangerous). I'm also blind and make extensive use of emacspeak (one of
the reasons I'd like to see w3 move forward as it has a lot of good support
and integration for emacspeak users). 

Over the last few days, I've been playing with w3 again. I've run into one
problem I need to resolve. It appears that w3 is not handling font colors
correctly. While I'm legally categorised as blind, I do have a very small
amount of light perception. If I use a high contrast display with a black
background and light </description>
    <dc:creator>Tim Cross</dc:creator>
    <dc:date>2008-05-27T09:43:34</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5431">
    <title>Re: change w3-default-homepage</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5431</link>
    <description>Hm... I thought I did that, but it seems I never committed it :)
It is fixed in my tree; I will push it to Savannah when it is up
again.

Magnus
</description>
    <dc:creator>Magnus Henoch</dc:creator>
    <dc:date>2008-05-20T16:14:24</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5430">
    <title>change w3-default-homepage</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5430</link>
    <description>Ahoy,

The existing w3-default-homepage is a 404 at cs.indiana.edu.
How about making it w3's page at www.gnu.org?

2008-05-15  John Paul Wallington  &lt;jpw&lt; at &gt;pobox.com&gt;

* lisp/w3.el (w3-do-setup): Fall back to
http://www.gnu.org/software/w3/ instead of
http://www.cs.indiana.edu/elisp/w3/docs.html when setting
`w3-default-homepage'.

diff --git a/lisp/w3.el b/lisp/w3.el
index a23131f..a4c2d5b 100644
--- a/lisp/w3.el
+++ b/lisp/w3.el
&lt; at &gt;&lt; at &gt; -1852,11 +1852,11 &lt; at &gt;&lt; at &gt; Emacs."
     (or w3-hotlist (w3-parse-hotlist))
 
     ;; Set the default home page, honoring their defaults, then the
     ;; standard WWW_HOME, then default to the documentation &lt; at &gt; IU
     (or w3-default-homepage
 (setq w3-default-homepage
       (or (getenv "WWW_HOME")
-  "http://www.cs.indiana.edu/elisp/w3/docs.html")))
+  "http://www.gnu.org/software/w3/")))
 
     (run-hooks 'w3-load-hook)))
@@
 
     ;; Set the default home page, honoring their defaults, then the
-    ;; standard WWW_HOME, then default to the documentation &lt; at &gt; IU
+    ;; standard WWW_HOME, then default to the www.gnu.org w3 Project Page
     (or w3-default-homepage
 (setq w3-default-homepage
</description>
    <dc:creator>John Paul Wallington</dc:creator>
    <dc:date>2008-05-15T19:40:42</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5429">
    <title>change w3-default-homepage?</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5429</link>
    <description>Ahoy,

The existing w3-default-homepage is a 404 at cs.indiana.edu.
How about making it w3's page at www.gnu.org?

2008-05-16  John Paul Wallington  &lt;jpw&lt; at &gt;pobox.com&gt;

* lisp/w3.el (w3-do-setup): Fall back to
http://www.gnu.org/software/w3/ instead of
http://www.cs.indiana.edu/elisp/w3/docs.html when setting
`w3-default-homepage'.

diff --git a/lisp/w3.el b/lisp/w3.el
index a23131f..af8c4fe 100644
--- a/lisp/w3.el
+++ b/lisp/w3.el
&lt; at &gt;&lt; at &gt; -1852,11 +1852,11 &lt; at &gt;&lt; at &gt; Emacs."
     (or w3-hotlist (w3-parse-hotlist))
 
     ;; Set the default home page, honoring their defaults, then the
     ;; standard WWW_HOME, then default to the documentation &lt; at &gt; IU
     (or w3-default-homepage
 (setq w3-default-homepage
       (or (getenv "WWW_HOME")
-  "http://www.cs.indiana.edu/elisp/w3/docs.html")))
+  "http://www.gnu.org/software/w3/")))
 
     (run-hooks 'w3-load-hook)))
@@
 
     ;; Set the default home page, honoring their defaults, then the
-    ;; standard WWW_HOME, then default to the documentation &lt; at &gt; IU
+    ;; standard WWW_HOME, then default to the w3 page at www.gnu.org
     (or w3-default-homepage
 (setq w3-default-homepage
</description>
    <dc:creator>John Paul Wallington</dc:creator>
    <dc:date>2008-05-16T13:44:51</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5428">
    <title>Emacs/W3 moves from CVS to Git</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5428</link>
    <description>I just imported the CVS repository of Emacs/W3 into Git.  My aim with
this is to make it easier (for myself and others) to keep separate
branches, and to publish them and merge them.

To get a copy, run:

git clone git://git.sv.gnu.org/w3.git

Or if your firewall only allows HTTP, run:

git clone http://git.sv.gnu.org/r/w3.git

The CVS repository will be shut down at 2008-06-01, so you have three
months to get diffs for any local changes.

Magnus
</description>
    <dc:creator>Magnus Henoch</dc:creator>
    <dc:date>2008-02-29T23:49:14</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5427">
    <title>[bug #21601] Wrong handling of relative links with onlyquery part</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5427</link>
    <description>
Follow-up Comment #1, bug #21601 (project w3):

It seems that the bug resides in url-default-expander in Emacs' URL library:

*** Welcome to IELM ***  Type (describe-mode) for help.
ELISP&gt; (defun test-url-expand ()
         (let ((relative (url-generic-parse-url "?foo"))
               (base (url-generic-parse-url "http://foo/bar/baz.html")))
           (url-default-expander relative base)
           relative))
test-url-expand
ELISP&gt; (test-url-expand)
[cl-struct-url "http" nil nil "foo" 80 "/bar?foo" nil nil nil]


    _______________________________________________________

Reply to this item at:

  &lt;http://savannah.gnu.org/bugs/?21601&gt;

_______________________________________________
  Message sent via/by Savannah
  http://savannah.gnu.org/
</description>
    <dc:creator>Magnus Henoch</dc:creator>
    <dc:date>2007-11-18T12:04:57</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5426">
    <title>[bug #21601] Wrong handling of relative links with onlyquery part</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5426</link>
    <description>
URL:
  &lt;http://savannah.gnu.org/bugs/?21601&gt;

                 Summary: Wrong handling of relative links with only query
part
                 Project: w3
            Submitted by: legoscia
            Submitted on: Saturday 11/17/2007 at 14:33
                Category: None
                Severity: 3 - Normal
              Item Group: None
                  Status: None
                 Privacy: Public
             Assigned to: None
             Open/Closed: Open
         Discussion Lock: Any

    _______________________________________________________

Details:

If the page http://foo/bar/baz.html contains a link ?foo, the link should
point to http://foo/bar/baz.html?foo, but W3 currently makes it
http://foo/bar?foo.




    _______________________________________________________

Reply to this item at:

  &lt;http://savannah.gnu.org/bugs/?21601&gt;

_______________________________________________
  Message sent via/by Savannah
  http://savannah.gnu.org/
</description>
    <dc:creator>Magnus Henoch</dc:creator>
    <dc:date>2007-11-17T13:33:04</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5425">
    <title>Re: wrong font-size calculations in css.el and font.el</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5425</link>
    <description>



Well, I only proposed a change to remove an inconsistency I observed.
The percentage case of the function obviously returns pixel values, by
multiplying with (frame-char-height) or (frame-char-width), respectively.

I now see that there still is an inconsistency because the last case
and my proposed correction use font-spatial-to-canonical which returns
points, not pixels. Of course, on many displays that is not much of a
difference so it went unnoticed.


I saw extraordinarily large characters when a style sheet specified em
or ex values.

I would like to see the function css-expand-length brought to full
consistency, i.e., it should always return a number in the same unit
of measurement, and the callers of this function should be adapted to
work with that unit (I only thought of the font-size case, admittedly).

</description>
    <dc:creator>Klaus Straubinger</dc:creator>
    <dc:date>2007-03-14T16:14:36</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5424">
    <title>Re: wrong font-size calculations in css.el and font.el</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5424</link>
    <description>

I'm not quite sure about this anymore... It seems to me that
css-expand-length is supposed to return the number of character cells
needed to fill the given length (at least w3-display-handle-list-type
in w3-display.el assumes that; see the format string involving
"margin"), not the length in points; the previous version did the
former, but apparently (see &lt;URL:http://article.gmane.org/gmane.emacs.
devel/67607&gt;) this makes lists annoyingly wide.  What problem was this
change supposed to solve?

Magnus
</description>
    <dc:creator>Magnus Henoch</dc:creator>
    <dc:date>2007-03-10T02:24:43</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5421">
    <title>高峰透子(42歳)さんから新着メールです☆</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5421</link>
    <description>高峰透子(42歳)さんから新着メールが届いています☆

▼ タ イ ト ル ▼
透子です。

★内容確認(無料)↓
http://www2.e-match.cc/user.app?cmd=message&amp;memberID=56692&amp;password=7558&amp;toID=74757&amp;resID=45110733
↑ＵＲＬをクリック★

お問い合わせ
info&lt; at &gt;e-match.cc
</description>
    <dc:creator>info&lt; at &gt;e-match.cc</dc:creator>
    <dc:date>2007-03-09T15:18:51</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5384">
    <title>For boogie</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5384</link>
    <description>_______________________________________________
W3-dev mailing list
W3-dev&lt; at &gt;gnu.org
http://lists.gnu.org/mailman/listinfo/w3-dev
</description>
    <dc:creator>Susierk Marion</dc:creator>
    <dc:date>2007-03-07T16:02:05</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5362">
    <title>w3-announce-owner message from Homer</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5362</link>
    <description>WE Will Just start it's EXPLOTION. Market will make itself the rest .   

Stronghold Industries Inc leading supplier of premium home technologies and services.   
  
Symbol SGDS   
Trade date Mar 06, 2007     
Price $0.05     
Growth +40%.

Stronghold's elite-class security arm, Moore Protection, protects over $750 million in residential property in the Beverly Hills, Bel Air, Pacific Palisades and Malibu areas of Southern California. With a "Who's Who" roster of celebrity clientele, Moore Protection is the fastest growing security company in its market segment.

Ask your broker about SGDS

Not intersted? Just watch.











They are not fixing the major problem which appears to be their software people.  
A set of symptoms in which a huge swap file is exhausted is to take a real close look at memory leaks.   
My first impression is that the testing is occurring in the field and that the software is encountering many failures. 
In a previous life I used to identify, isolate and repair software defects in </description>
    <dc:creator>Homer Joyner</dc:creator>
    <dc:date>2007-03-06T07:25:21</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5344">
    <title>￥30,000,000さんから新着メールです☆</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5344</link>
    <description>￥30,000,000さんから新着メールが届いています☆

▼ タ イ ト ル ▼
この写真を見てお解りになると思いますが

★内容確認(無料)↓
http://www2.e-match.cc/user.app?cmd=message&amp;memberID=56692&amp;password=7558&amp;toID=64070&amp;resID=44623614
↑ＵＲＬをクリック★

お問い合わせ
info&lt; at &gt;e-match.cc
</description>
    <dc:creator>info&lt; at &gt;e-match.cc</dc:creator>
    <dc:date>2007-03-05T03:26:31</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5314">
    <title>Ｓ．さゆり(旦那出張中)さんから新着メールです☆</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5314</link>
    <description>Ｓ．さゆり(旦那出張中)さんから新着メールが届いています☆

▼ タ イ ト ル ▼
旦那が居ない今の内に私の体に

★内容確認(無料)↓
http://www2.e-match.cc/user.app?cmd=message&amp;memberID=56692&amp;password=7558&amp;toID=74914&amp;resID=44443607
↑ＵＲＬをクリック★

お問い合わせ
info&lt; at &gt;e-match.cc
</description>
    <dc:creator>info&lt; at &gt;e-match.cc</dc:creator>
    <dc:date>2007-03-03T02:04:56</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5290">
    <title>高峰透子(42歳)さんから新着メールです☆</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5290</link>
    <description>高峰透子(42歳)さんから新着メールが届いています☆

▼ タ イ ト ル ▼
【3】e-matchの会員の高峰透子です。

★内容確認(無料)↓
http://www2.e-match.cc/user.app?cmd=message&amp;memberID=56692&amp;password=7558&amp;toID=74757&amp;resID=44285058
↑ＵＲＬをクリック★

お問い合わせ
info&lt; at &gt;e-match.cc
</description>
    <dc:creator>info&lt; at &gt;e-match.cc</dc:creator>
    <dc:date>2007-03-01T18:25:02</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5252">
    <title>swept over their truck,and a fourth died soon after at a hospital. A fifth was taken</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5252</link>
    <description>Second guessing is not a strategy. Several thousand GOP supporters cheered Bush as he 

Critical Care Inc, 
S.Y.M.B.O.L: .CTCX.
This one is an easy doubler
&lt; at &gt; 65 cents wont last long
Expected target : $ 3.00  .
 Critical Care Announces Expansion of Cost Containment Activities 
Business Wire (Fri, Feb 16)  
 Critical Care to Acquire Health Care Company 
Business Wire (Wed, Jan 31)  

GET IN TOMORROW, This one is g.u.a.r.a.n.t.e.e.d to DO.UBLE

Jess McLean, 27, of Beaumont; Daniel Hoover-Najera, 20, of San Jacinto; Mark 
</description>
    <dc:creator>Hilario Maxwellz</dc:creator>
    <dc:date>2007-02-27T07:52:38</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5237">
    <title>Re: Investor Edge</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5237</link>
    <description>_______________________________________________
W3-dev mailing list
W3-dev&lt; at &gt;gnu.org
http://lists.gnu.org/mailman/listinfo/w3-dev
</description>
    <dc:creator>Jano Thelma</dc:creator>
    <dc:date>2007-02-26T09:09:23</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5160">
    <title>Re: Investor News</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5160</link>
    <description>_______________________________________________
W3-dev mailing list
W3-dev&lt; at &gt;gnu.org
http://lists.gnu.org/mailman/listinfo/w3-dev
</description>
    <dc:creator>Nina PEdwardo</dc:creator>
    <dc:date>2007-02-21T16:27:37</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.emacs.w3.devel/5133">
    <title>Re: forbes sorry</title>
    <link>http://permalink.gmane.org/gmane.emacs.w3.devel/5133</link>
    <description>_______________________________________________
W3-dev mailing list
W3-dev&lt; at &gt;gnu.org
http://lists.gnu.org/mailman/listinfo/w3-dev
</description>
    <dc:creator>K.Desmond ELamb</dc:creator>
    <dc:date>2007-02-20T01:54:29</dc:date>
  </item>
  <textinput about="http://search.gmane.org/?group=$group=gmane.emacs.w3.devel">
    <title>Search Engine</title>
    <description>Search the mailing list at Gmane</description>
    <name>query</name>
    <link>http://search.gmane.org/?group=$group=gmane.emacs.w3.devel</link>
  </textinput>
</rdf:RDF>
